@@ -141,6 +141,8 @@ QVariant AppsModel::data(const QModelIndex &index, int role) const
         return entry->name();
     } else if (role == Qt::DecorationRole) {
         return entry->icon();
+    } else if (role == Kicker::CompactNameRole) {
+        return entry->compactName();
     } else if (role == Kicker::DescriptionRole) {
         return entry->description();
     } else if (role == Kicker::FavoriteIdRole && entry->type() == AbstractEntry::RunnableType) {
@@ -427,6 +429,9 @@ void AppsModel::setAppNameFormat(int format)
         refresh();
 
         Q_EMIT appNameFormatChanged();
+        for (AbstractEntry *entry : std::as_const(m_entryList)) {
+            entry->reload();
+        }
     }
 }
 
