@@ -38,12 +38,11 @@ class CKCmFontInst : public KCModule
     Q_OBJECT
 
 public:
-    explicit CKCmFontInst(QWidget *parent = nullptr, const QVariantList &list = QVariantList());
+    explicit CKCmFontInst(QObject *parent, const KPluginMetaData &data);
     ~CKCmFontInst() override;
 
 public Q_SLOTS:
 
-    QString quickHelp() const override;
     void previewMenu(const QPoint &pos);
     void splitterMoved();
     void fontsSelected(const QModelIndexList &list);
