@@ -11,6 +11,7 @@
 #include <QDBusObjectPath>
 #include <QObject>
 #include <QPointer>
+#include <QRect>
 #include <QUrl>
 
 #include <optional>
@@ -69,9 +70,9 @@ class User : public QObject
 
     Q_PROPERTY(QUrl face READ face WRITE setFace NOTIFY faceChanged)
 
-    Q_PROPERTY(bool faceValid READ faceValid NOTIFY faceValidChanged)
+    Q_PROPERTY(QRect faceCrop READ faceCrop WRITE setFaceCrop)
 
-    Q_PROPERTY(QString password READ _ WRITE setPassword)
+    Q_PROPERTY(bool faceValid READ faceValid NOTIFY faceValidChanged)
 
     Q_PROPERTY(bool loggedIn READ loggedIn CONSTANT)
 
@@ -93,29 +94,25 @@ public:
     bool loggedIn() const;
     bool administrator() const;
     QDBusObjectPath path() const;
+    QRect faceCrop() const;
 
     void setName(const QString &value);
     void setRealName(const QString &value);
     void setEmail(const QString &value);
     void setFace(const QUrl &value);
-    void setPassword(const QString &value);
     void setAdministrator(bool value);
     void setPath(const QDBusObjectPath &path);
+    void setFaceCrop(const QRect &rect);
 
     void loadData();
 
-    QString _()
-    {
-        return QString();
-    };
-
 public Q_SLOTS:
     Q_SCRIPTABLE void apply();
     Q_SCRIPTABLE bool usesDefaultWallet();
     Q_SCRIPTABLE void changeWalletPassword();
+    Q_SCRIPTABLE void setPassword(const QString &value);
 
 Q_SIGNALS:
-
     void dataChanged();
     void uidChanged();
     void nameChanged();
@@ -131,14 +128,15 @@ Q_SIGNALS:
 private:
     qulonglong mUid = 0;
     int mOriginalUid = 0;
-    QString mName = QString();
-    QString mOriginalName = QString();
-    QString mRealName = QString();
-    QString mOriginalRealName = QString();
-    QString mEmail = QString();
-    QString mOriginalEmail = QString();
-    QUrl mFace = QUrl();
-    QUrl mOriginalFace = QUrl();
+    QString mName;
+    QString mOriginalName;
+    QString mRealName;
+    QString mOriginalRealName;
+    QString mEmail;
+    QString mOriginalEmail;
+    QUrl mFace;
+    QUrl mOriginalFace;
+    QRect mFaceCrop = QRect(0, -1, 0, -1);
     bool mAdministrator = false;
     bool mOriginalAdministrator = false;
     bool mFaceValid = false;
