@@ -8,29 +8,29 @@
 
 #pragma once
 
-#include <QAction>
 #include <QMimeData>
 
 class QalculateEngine;
 
-#include <krunner/abstractrunner.h>
+#include <KRunner/AbstractRunner>
+#include <KRunner/Action>
 
 /**
  * This class evaluates the basic expressions given in the interface.
  */
-class CalculatorRunner : public Plasma::AbstractRunner
+class CalculatorRunner : public KRunner::AbstractRunner
 {
     Q_OBJECT
 
 public:
-    CalculatorRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    CalculatorRunner(QObject *parent, const KPluginMetaData &metaData);
     ~CalculatorRunner() override;
 
-    void match(Plasma::RunnerContext &context) override;
+    void match(KRunner::RunnerContext &context) override;
 
 protected Q_SLOTS:
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
-    QMimeData *mimeDataForMatch(const Plasma::QueryMatch &match) override;
+    void run(const KRunner::RunnerContext &context, const KRunner::QueryMatch &match) override;
+    QMimeData *mimeDataForMatch(const KRunner::QueryMatch &match) override;
 
 private:
     QString calculate(const QString &term, bool *isApproximate, int base, const QString &customBase);
@@ -38,5 +38,5 @@ private:
     void userFriendlySubstitutions(QString &cmd);
 
     std::unique_ptr<QalculateEngine> m_engine;
-    QList<QAction *> m_actions;
+    const KRunner::Actions m_actions;
 };
