@@ -41,7 +41,7 @@ void ShellRunner::match(KRunner::RunnerContext &context)
     if (parsingResult.has_value()) {
         const QString command = parsingResult.value();
         KRunner::QueryMatch match(this);
-        match.setId(QStringLiteral("exec://") + command);
+        match.setId(QString(u"exec://" + command));
         match.setCategoryRelevance(KRunner::QueryMatch::CategoryRelevance::Highest);
         match.setIcon(m_matchIcon);
         match.setText(i18n("Run %1", context.query()));
@@ -59,7 +59,7 @@ void ShellRunner::run(const KRunner::RunnerContext &context, const KRunner::Quer
         const QStringList list = data.at(1).toStringList();
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         for (const QString &str : list) {
-            const int pos = str.indexOf('=');
+            const int pos = str.indexOf(u'=');
             env.insert(str.left(pos), str.mid(pos + 1));
         }
         auto job = new KTerminalLauncherJob(data.at(0).toString());
