@@ -13,6 +13,7 @@
 
 #include <Plasma/Containment>
 #include <Plasma/PluginLoader>
+#include <PlasmaQuick/AppletQuickItem>
 
 AlternativesHelper::AlternativesHelper(Plasma::Applet *applet, QObject *parent)
     : QObject(parent)
@@ -36,7 +37,7 @@ QString AlternativesHelper::currentPlugin() const
 
 QQuickItem *AlternativesHelper::applet() const
 {
-    return m_applet->property("_plasma_graphicObject").value<QQuickItem *>();
+    return PlasmaQuick::AppletQuickItem::itemForApplet(m_applet);
 }
 
 void AlternativesHelper::loadAlternative(const QString &plugin)
@@ -50,8 +51,8 @@ void AlternativesHelper::loadAlternative(const QString &plugin)
         return;
     }
 
-    QQuickItem *appletItem = m_applet->property("_plasma_graphicObject").value<QQuickItem *>();
-    QQuickItem *contItem = cont->property("_plasma_graphicObject").value<QQuickItem *>();
+    QQuickItem *appletItem = PlasmaQuick::AppletQuickItem::itemForApplet(m_applet);
+    QQuickItem *contItem = PlasmaQuick::AppletQuickItem::itemForApplet(cont);
     if (!appletItem || !contItem) {
         return;
     }
@@ -62,13 +63,7 @@ void AlternativesHelper::loadAlternative(const QString &plugin)
 
     const QPoint newPos = appletItem->mapToItem(contItem, QPointF(0, 0)).toPoint();
 
-    Plasma::Applet *newApplet = nullptr;
-    QMetaObject::invokeMethod(contItem,
-                              "createApplet",
-                              Q_RETURN_ARG(Plasma::Applet *, newApplet),
-                              Q_ARG(QString, plugin),
-                              Q_ARG(QVariantList, QVariantList()),
-                              Q_ARG(QPoint, newPos));
+    Plasma::Applet *newApplet = cont->createApplet(plugin, {}, QRectF(newPos, QSizeF()));
 
     if (newApplet) {
         newApplet->setGlobalShortcut(shortcut);
